@@ -1,8 +1,7 @@
 # pylint: disable=missing-docstring
 
-__copyright__ = "2020-2021, Applied Brain Research"
 __license__ = "Free for non-commercial use; see LICENSE.rst"
-from keras_spiking import callbacks, layers, model_energy, regularizers
+from keras_spiking import callbacks, constraints, layers, model_energy, regularizers
 from keras_spiking.config import default
 from keras_spiking.layers import (
     Alpha,
@@ -13,4 +12,5 @@ from keras_spiking.layers import (
     SpikingActivationCell,
 )
 from keras_spiking.model_energy import ModelEnergy
+from keras_spiking.version import copyright as __copyright__
 from keras_spiking.version import version as __version__
