@@ -454,7 +454,7 @@ class SpikingActivation(KerasSpikingLayer):
         self,
         activation,
         *,
-        dt=0.001,
+        dt=None,
         seed=None,
         spiking_aware_training=True,
         return_sequences=True,
@@ -515,15 +515,17 @@ class LowpassCell(KerasSpikingCell):
     .. testcode::
 
         my_layer = tf.keras.layers.RNN(
-            keras_spiking.LowpassCell(size=10, tau=0.01)
+            keras_spiking.LowpassCell(size=10, tau_initializer=0.01)
         )
 
     Parameters
     ----------
     size : int or tuple of int or ``tf.TensorShape``
         Input/output shape of the layer (not including batch/time dimensions).
-    tau : float
-        Time constant of filter (in seconds).
+    tau_initializer : float or str or ``tf.keras.initializers.Initializer``
+        Initial value of time constant of filter (in seconds). Passing a float will
+        initialize it to that value, or any standard Keras initializer can
+        be used.
     dt : float
         Length of time (in seconds) represented by one time step. If None, uses
         `keras_spiking.default.dt <keras_spiking.config.DefaultManager>`
@@ -535,6 +537,12 @@ class LowpassCell(KerasSpikingCell):
         then we often don't need to filter them either).
     level_initializer : str or ``tf.keras.initializers.Initializer``
         Initializer for filter state.
+    initial_level_constraint : str or ``tf.keras.constraints.Constraint``
+        Constraint for ``initial_level``.
+    tau_constraint : str or ``tf.keras.constraints.Constraint``
+        Constraint for ``tau``. For example, `.Mean` will share the same
+        time constant across all of the lowpass filters. The time constant is always
+        clipped to be positive in the forward pass for numerical stability.
     kwargs : dict
         Passed on to `tf.keras.layers.Layer
         <https://www.tensorflow.org/api_docs/python/tf/keras/layers/Layer>`_.
@@ -543,12 +551,13 @@ class LowpassCell(KerasSpikingCell):
     def __init__(
         self,
         size,
-        tau,
+        tau_initializer,
         *,
         dt=None,
-        # TODO: better name for this parameter?
-        apply_during_training=True,
+        apply_during_training=True,  # TODO: better name for this parameter?
         level_initializer="zeros",
+        initial_level_constraint=None,
+        tau_constraint=None,
         **kwargs,
     ):
         super().__init__(
@@ -558,12 +567,17 @@ class LowpassCell(KerasSpikingCell):
             **kwargs,
         )
 
-        if tau <= 0:
-            raise ValueError("tau must be a positive number")
-
-        self.tau = tau
+        self.tau_initializer = (
+            tf.keras.initializers.constant(tau_initializer)
+            if isinstance(tau_initializer, (int, float))
+            else tf.keras.initializers.get(tau_initializer)
+        )
         self.apply_during_training = apply_during_training
         self.level_initializer = tf.initializers.get(level_initializer)
+        self.initial_level_constraint = tf.keras.constraints.get(
+            initial_level_constraint
+        )
+        self.tau_constraint = tf.keras.constraints.get(tau_constraint)
 
     def build(self, input_shapes):
         """Build parameters associated with this layer."""
@@ -575,14 +589,15 @@ class LowpassCell(KerasSpikingCell):
             shape=[1] + self.size.as_list(),
             initializer=self.level_initializer,
             trainable=self.apply_during_training,
+            constraint=self.initial_level_constraint,
         )
 
-        self.tau_var = self.add_weight(
-            name="tau_var",
+        self.tau = self.add_weight(
+            name="tau",
             shape=[1] + self.state_size.as_list(),
-            initializer=tf.initializers.constant(np.ones(self.state_size) * self.tau),
+            initializer=self.tau_initializer,
             trainable=self.apply_during_training,
-            constraint=tf.keras.constraints.NonNeg(),
+            constraint=self.tau_constraint,
         )
 
     def get_initial_state(self, inputs=None, batch_size=None, dtype=None):
@@ -593,7 +608,7 @@ class LowpassCell(KerasSpikingCell):
         # apply ZOH discretization
         tau = tf.exp(
             -self.dt  # pylint: disable=invalid-unary-operand-type
-            / (self.tau_var + 1e-8)
+            / tf.maximum(self.tau, 1e-8)
         )
 
         x = (1 - tau) * inputs + tau * states[0]
@@ -609,12 +624,16 @@ class LowpassCell(KerasSpikingCell):
         cfg.update(
             dict(
                 size=self.size,
-                tau=self.tau,
+                tau_initializer=tf.keras.initializers.serialize(self.tau_initializer),
                 dt=self.dt,
                 apply_during_training=self.apply_during_training,
                 level_initializer=tf.keras.initializers.serialize(
                     self.level_initializer
                 ),
+                initial_level_constraint=tf.keras.constraints.serialize(
+                    self.initial_level_constraint
+                ),
+                tau_constraint=tf.keras.constraints.serialize(self.tau_constraint),
             )
         )
 
@@ -647,8 +666,10 @@ class Lowpass(KerasSpikingLayer):
 
     Parameters
     ----------
-    tau : float
-        Time constant of filter (in seconds).
+    tau_initializer : float or str or ``tf.keras.initializers.Initializer``
+        Initial value of time constant of filter (in seconds). Passing a float will
+        initialize it to that value, or any standard Keras initializer can
+        be used.
     dt : float
         Length of time (in seconds) represented by one time step. If None, uses
         `keras_spiking.default.dt <keras_spiking.config.DefaultManager>`
@@ -660,6 +681,12 @@ class Lowpass(KerasSpikingLayer):
         then we often don't need to filter them either).
     level_initializer : str or ``tf.keras.initializers.Initializer``
         Initializer for filter state.
+    initial_level_constraint : str or ``tf.keras.constraints.Constraint``
+        Constraint for ``initial_level``.
+    tau_constraint : str or ``tf.keras.constraints.Constraint``
+        Constraint for ``tau``. For example, `.Mean` will share the same
+        time constant across all of the lowpass filters. The time constant is always
+        clipped to be positive in the forward pass for numerical stability.
     return_sequences : bool
         Whether to return the full sequence of filtered output (default),
         or just the output on the last timestep.
@@ -688,11 +715,13 @@ class Lowpass(KerasSpikingLayer):
 
     def __init__(
         self,
-        tau,
+        tau_initializer,
         *,
-        dt=0.001,
+        dt=None,
         apply_during_training=True,
         level_initializer="zeros",
+        initial_level_constraint=None,
+        tau_constraint=None,
         return_sequences=True,
         return_state=False,
         stateful=False,
@@ -710,28 +739,42 @@ class Lowpass(KerasSpikingLayer):
             **kwargs,
         )
 
-        self.tau = tau
+        self.tau_initializer = (
+            tf.keras.initializers.constant(tau_initializer)
+            if isinstance(tau_initializer, (int, float))
+            else tf.keras.initializers.get(tau_initializer)
+        )
         self.apply_during_training = apply_during_training
         self.level_initializer = tf.keras.initializers.get(level_initializer)
+        self.initial_level_constraint = tf.keras.constraints.get(
+            initial_level_constraint
+        )
+        self.tau_constraint = tf.keras.constraints.get(tau_constraint)
 
     def build_cell(self, input_shapes):
         return LowpassCell(
             size=input_shapes[2:],
-            tau=self.tau,
+            tau_initializer=self.tau_initializer,
             dt=self.dt,
             apply_during_training=self.apply_during_training,
             level_initializer=self.level_initializer,
+            initial_level_constraint=self.initial_level_constraint,
+            tau_constraint=self.tau_constraint,
         )
 
     def get_config(self):
         cfg = super().get_config()
         cfg.update(
             dict(
-                tau=self.tau,
+                tau_initializer=tf.keras.initializers.serialize(self.tau_initializer),
                 apply_during_training=self.apply_during_training,
                 level_initializer=tf.keras.initializers.serialize(
                     self.level_initializer
                 ),
+                initial_level_constraint=tf.keras.constraints.serialize(
+                    self.initial_level_constraint
+                ),
+                tau_constraint=tf.keras.constraints.serialize(self.tau_constraint),
             )
         )
 
@@ -752,14 +795,18 @@ class AlphaCell(KerasSpikingCell):
 
     .. testcode::
 
-        my_layer = tf.keras.layers.RNN(keras_spiking.AlphaCell(size=10, tau=0.01))
+        my_layer = tf.keras.layers.RNN(
+            keras_spiking.AlphaCell(size=10, tau_initializer=0.01)
+        )
 
     Parameters
     ----------
     size : int or tuple of int or ``tf.TensorShape``
         Input/output shape of the layer (not including batch/time dimensions).
-    tau : float
-        Time constant of filter (in seconds).
+    tau_initializer : float or str or ``tf.keras.initializers.Initializer``
+        Initial value of time constant of filter (in seconds). Passing a float will
+        initialize it to that value, or any standard Keras initializer can
+        be used.
     dt : float
         Length of time (in seconds) represented by one time step. If None, uses
         `keras_spiking.default.dt <keras_spiking.config.DefaultManager>`
@@ -771,6 +818,12 @@ class AlphaCell(KerasSpikingCell):
         then we often don't need to filter them either).
     level_initializer : str or ``tf.keras.initializers.Initializer``
         Initializer for filter state.
+    initial_level_constraint : str or ``tf.keras.constraints.Constraint``
+        Constraint for ``initial_level``.
+    tau_constraint : str or ``tf.keras.constraints.Constraint``
+        Constraint for ``tau``. For example, `.Mean` will share the same
+        time constant across all of the lowpass filters. The time constant is always
+        clipped to be positive in the forward pass for numerical stability.
     kwargs : dict
         Passed on to `tf.keras.layers.Layer
         <https://www.tensorflow.org/api_docs/python/tf/keras/layers/Layer>`_.
@@ -779,12 +832,13 @@ class AlphaCell(KerasSpikingCell):
     def __init__(
         self,
         size,
-        tau,
+        tau_initializer,
         *,
         dt=None,
-        # TODO: better name for this parameter?
-        apply_during_training=True,
+        apply_during_training=True,  # TODO: better name for this parameter?
         level_initializer="zeros",
+        initial_level_constraint=None,
+        tau_constraint=None,
         **kwargs,
     ):
         super().__init__(
@@ -795,13 +849,18 @@ class AlphaCell(KerasSpikingCell):
             **kwargs,
         )
 
-        if tau <= 0:
-            raise ValueError("tau must be a positive number")
-
         self.flat_size = np.prod(self.size)
-        self.tau = tau
+        self.tau_initializer = (
+            tf.keras.initializers.constant(tau_initializer)
+            if isinstance(tau_initializer, (int, float))
+            else tf.keras.initializers.get(tau_initializer)
+        )
         self.apply_during_training = apply_during_training
         self.level_initializer = tf.initializers.get(level_initializer)
+        self.initial_level_constraint = tf.keras.constraints.get(
+            initial_level_constraint
+        )
+        self.tau_constraint = tf.keras.constraints.get(tau_constraint)
 
     def build(self, input_shapes):
         """Build parameters associated with this layer."""
@@ -813,14 +872,15 @@ class AlphaCell(KerasSpikingCell):
             shape=(self.flat_size,),
             initializer=self.level_initializer,
             trainable=self.apply_during_training,
+            constraint=self.initial_level_constraint,
         )
 
-        self.tau_var = self.add_weight(
-            name="tau_var",
+        self.tau = self.add_weight(
+            name="tau",
             shape=(self.flat_size,),
-            initializer=tf.initializers.constant(np.ones(self.flat_size) * self.tau),
+            initializer=self.tau_initializer,
             trainable=self.apply_during_training,
-            constraint=tf.keras.constraints.NonNeg(),
+            constraint=self.tau_constraint,
         )
 
     def get_initial_state(self, inputs=None, batch_size=None, dtype=None):
@@ -846,7 +906,7 @@ class AlphaCell(KerasSpikingCell):
         #     AB = sy.Matrix([[-2/tau, -1/tau**2, 1/tau**2], [1, 0, 0], [0, 0, 0]])
         #     dAB = sy.exp(dt * AB).simplify()
         #     dA, dB = dAB[:2, :2], dAB[:2, 2:]
-        tau = self.tau_var[:, None, None] + 1e-8
+        tau = tf.maximum(self.tau[:, None, None], 1e-8)
         dt_tau = self.dt / tau
         dt_tau2 = dt_tau / tau
         exp_dt_tau = tf.exp(-dt_tau)
@@ -883,12 +943,16 @@ class AlphaCell(KerasSpikingCell):
         cfg.update(
             dict(
                 size=self.size,
-                tau=self.tau,
+                tau_initializer=tf.keras.initializers.serialize(self.tau_initializer),
                 dt=self.dt,
                 apply_during_training=self.apply_during_training,
                 level_initializer=tf.keras.initializers.serialize(
                     self.level_initializer
                 ),
+                initial_level_constraint=tf.keras.constraints.serialize(
+                    self.initial_level_constraint
+                ),
+                tau_constraint=tf.keras.constraints.serialize(self.tau_constraint),
             )
         )
 
@@ -921,8 +985,10 @@ class Alpha(KerasSpikingLayer):
 
     Parameters
     ----------
-    tau : float
-        Time constant of filter (in seconds).
+    tau_initializer : float or str or ``tf.keras.initializers.Initializer``
+        Initial value of time constant of filter (in seconds). Passing a float will
+        initialize it to that value, or any standard Keras initializer can
+        be used.
     dt : float
         Length of time (in seconds) represented by one time step. If None, uses
         `keras_spiking.default.dt <keras_spiking.config.DefaultManager>`
@@ -934,6 +1000,12 @@ class Alpha(KerasSpikingLayer):
         then we often don't need to filter them either).
     level_initializer : str or ``tf.keras.initializers.Initializer``
         Initializer for filter state.
+    initial_level_constraint : str or ``tf.keras.constraints.Constraint``
+        Constraint for ``initial_level``.
+    tau_constraint : str or ``tf.keras.constraints.Constraint``
+        Constraint for ``tau``. For example, `.Mean` will share the same
+        time constant across all of the lowpass filters. The time constant is always
+        clipped to be positive in the forward pass for numerical stability.
     return_sequences : bool
         Whether to return the full sequence of filtered output (default),
         or just the output on the last timestep.
@@ -962,11 +1034,13 @@ class Alpha(KerasSpikingLayer):
 
     def __init__(
         self,
-        tau,
+        tau_initializer,
         *,
-        dt=0.001,
+        dt=None,
         apply_during_training=True,
         level_initializer="zeros",
+        initial_level_constraint=None,
+        tau_constraint=None,
         return_sequences=True,
         return_state=False,
         stateful=False,
@@ -984,28 +1058,38 @@ class Alpha(KerasSpikingLayer):
             **kwargs,
         )
 
-        self.tau = tau
+        self.tau_initializer = tau_initializer
         self.apply_during_training = apply_during_training
         self.level_initializer = tf.keras.initializers.get(level_initializer)
+        self.initial_level_constraint = tf.keras.constraints.get(
+            initial_level_constraint
+        )
+        self.tau_constraint = tf.keras.constraints.get(tau_constraint)
 
     def build_cell(self, input_shapes):
         return AlphaCell(
             size=input_shapes[2:],
-            tau=self.tau,
+            tau_initializer=self.tau_initializer,
             dt=self.dt,
             apply_during_training=self.apply_during_training,
             level_initializer=self.level_initializer,
+            initial_level_constraint=self.initial_level_constraint,
+            tau_constraint=self.tau_constraint,
         )
 
     def get_config(self):
         cfg = super().get_config()
         cfg.update(
             dict(
-                tau=self.tau,
+                tau_initializer=self.tau_initializer,
                 apply_during_training=self.apply_during_training,
                 level_initializer=tf.keras.initializers.serialize(
                     self.level_initializer
                 ),
+                initial_level_constraint=tf.keras.constraints.serialize(
+                    self.initial_level_constraint
+                ),
+                tau_constraint=tf.keras.constraints.serialize(self.tau_constraint),
             )
         )
 
